SWHIDs (SoftWare Hash IDentifiers)
----------------------------------

.. autosimple:: swh.web.api.views.identifiers.api_resolve_swhid

.. autosimple:: swh.web.api.views.identifiers.api_swhid_known

.. autosimple:: swh.web.api.views.raw.api_raw_object

